************************
Plotting classes
************************

MTplot class
=========================

.. autoclass:: MTfit.plot.plot_classes.MTplot
   :members:   

MTData class
=========================

.. autoclass:: MTfit.plot.plot_classes.MTData
   :members:  



_BasePlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._BasePlot
   :members:
   :private-members:
   :special-members:


_FocalSpherePlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._FocalSpherePlot
   :members:
   :inherited-members:
   :private-members:


_AmplitudePlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._AmplitudePlot
   :members:
   :inherited-members:
   :private-members:


_FaultPlanePlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._FaultPlanePlot
   :members:
   :inherited-members:
   :private-members:


_RiedeselJordanPlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._RiedeselJordanPlot
   :members:
   :inherited-members:
   :private-members:


_RadiationPlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._RadiationPlot
   :members:
   :inherited-members:
   :private-members:


_HudsonPlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._HudsonPlot
   :members:
   :inherited-members:
   :private-members:


_LunePlot class
=========================

.. autoclass:: MTfit.plot.plot_classes._LunePlot
   :members:
   :inherited-members:
   :private-members:
